pycollect — pycollect 0.0.0 documentation

### Navigation

- ☰
- pycollect-0.0.0 »
- Reference »

Fork me on GitHub

# pycollect

class `pycollect.` `PythonFileCollector`(enable_regex_patterns: bool = False, file_inclusion_patterns: Iterable[str] = None, file_exclusion_patterns: Iterable[str] = None, dir_inclusion_patterns: Iterable[str] = None, dir_exclusion_patterns: Iterable[str] = None)

  PythonFileCollector class provides general configurations and utility methods for collecting Python files

### Navigation

- index
- modules |
- next |
- previous |